@@ -42,6 +42,7 @@ from .type_defs import (
     CreateAccessPreviewResponseTypeDef,
     CreateAnalyzerResponseTypeDef,
     CriterionTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetAccessPreviewResponseTypeDef,
     GetAnalyzedResourceResponseTypeDef,
     GetAnalyzerResponseTypeDef,
@@ -110,7 +111,7 @@ class AccessAnalyzerClient(BaseClient):
 
     def apply_archive_rule(
         self, *, analyzerArn: str, ruleName: str, clientToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Retroactively applies the archive rule to existing findings that meet the
         archive rule criteria.
@@ -135,11 +136,19 @@ class AccessAnalyzerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client/#cancel_policy_generation)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client/#close)
+        """
+
     def create_access_preview(
         self,
         *,
         analyzerArn: str,
-        configurations: Mapping[str, "ConfigurationTypeDef"],
+        configurations: Mapping[str, ConfigurationTypeDef],
         clientToken: str = ...
     ) -> CreateAccessPreviewResponseTypeDef:
         """
@@ -155,7 +164,7 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerName: str,
         type: TypeType,
-        archiveRules: Sequence["InlineArchiveRuleTypeDef"] = ...,
+        archiveRules: Sequence[InlineArchiveRuleTypeDef] = ...,
         clientToken: str = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateAnalyzerResponseTypeDef:
@@ -170,10 +179,10 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Mapping[str, "CriterionTypeDef"],
+        filter: Mapping[str, CriterionTypeDef],
         ruleName: str,
         clientToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Creates an archive rule for the specified analyzer.
 
@@ -181,7 +190,9 @@ class AccessAnalyzerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client/#create_archive_rule)
         """
 
-    def delete_analyzer(self, *, analyzerName: str, clientToken: str = ...) -> None:
+    def delete_analyzer(
+        self, *, analyzerName: str, clientToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified analyzer.
 
@@ -191,7 +202,7 @@ class AccessAnalyzerClient(BaseClient):
 
     def delete_archive_rule(
         self, *, analyzerName: str, ruleName: str, clientToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified archive rule.
 
@@ -278,7 +289,7 @@ class AccessAnalyzerClient(BaseClient):
         *,
         accessPreviewId: str,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = ...,
+        filter: Mapping[str, CriterionTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListAccessPreviewFindingsResponseTypeDef:
@@ -340,10 +351,10 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = ...,
+        filter: Mapping[str, CriterionTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...,
-        sort: "SortCriteriaTypeDef" = ...
+        sort: SortCriteriaTypeDef = ...
     ) -> ListFindingsResponseTypeDef:
         """
         Retrieves a list of findings generated by the specified analyzer.
@@ -373,9 +384,9 @@ class AccessAnalyzerClient(BaseClient):
     def start_policy_generation(
         self,
         *,
-        policyGenerationDetails: "PolicyGenerationDetailsTypeDef",
+        policyGenerationDetails: PolicyGenerationDetailsTypeDef,
         clientToken: str = ...,
-        cloudTrailDetails: "CloudTrailDetailsTypeDef" = ...
+        cloudTrailDetails: CloudTrailDetailsTypeDef = ...
     ) -> StartPolicyGenerationResponseTypeDef:
         """
         Starts the policy generation request.
@@ -384,7 +395,9 @@ class AccessAnalyzerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client/#start_policy_generation)
         """
 
-    def start_resource_scan(self, *, analyzerArn: str, resourceArn: str) -> None:
+    def start_resource_scan(
+        self, *, analyzerArn: str, resourceArn: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Immediately starts a scan of the policies applied to the specified resource.
 
@@ -412,10 +425,10 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Mapping[str, "CriterionTypeDef"],
+        filter: Mapping[str, CriterionTypeDef],
         ruleName: str,
         clientToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the criteria and values for the specified archive rule.
 
@@ -431,7 +444,7 @@ class AccessAnalyzerClient(BaseClient):
         clientToken: str = ...,
         ids: Sequence[str] = ...,
         resourceArn: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the status for the specified findings.
 
